@@ -23,8 +23,7 @@ class wcdb_extractor(BasePlugin, DiscoveryPluginMixin):
     category = ["default", "active", "discovery"]
     priority = 99
 
-    parameters = (
-    )
+    parameters = ()
 
     def __init__(self):
         BasePlugin.__init__(self)
@@ -33,10 +32,10 @@ class wcdb_extractor(BasePlugin, DiscoveryPluginMixin):
         return fuzzresult.url.find(".svn/wc.d") > 0 and fuzzresult.code == 200
 
     def readwc(self, content):
-        '''
+        """
         Function shamesly copied (and adapted) from https://github.com/anantshri/svn-extractor/
         Credit (C) Anant Shrivastava http://anantshri.info
-        '''
+        """
         author_list = []
         list_items = None
         (fd, filename) = tempfile.mkstemp()
@@ -47,14 +46,18 @@ class wcdb_extractor(BasePlugin, DiscoveryPluginMixin):
         conn = sqlite3.connect(filename)
         c = conn.cursor()
         try:
-            c.execute('select local_relpath, ".svn/pristine/" || substr(checksum,7,2) || "/" || substr(checksum,7) || ".svn-base" as alpha from NODES where kind="file";')
+            c.execute(
+                'select local_relpath, ".svn/pristine/" || substr(checksum,7,2) || "/" || substr(checksum,7) || ".svn-base" as alpha from NODES where kind="file";'
+            )
             list_items = c.fetchall()
             # below functionality will find all usernames who have commited atleast once.
-            c.execute('select distinct changed_author from nodes;')
+            c.execute("select distinct changed_author from nodes;")
             author_list = [r[0] for r in c.fetchall()]
             c.close()
         except Exception:
-            raise FuzzExceptResourceParseError("Error reading wc.db, either database corrupt or invalid file")
+            raise FuzzExceptResourceParseError(
+                "Error reading wc.db, either database corrupt or invalid file"
+            )
 
         return author_list, list_items
 
@@ -62,7 +65,7 @@ class wcdb_extractor(BasePlugin, DiscoveryPluginMixin):
         author_list, list_items = self.readwc(fuzzresult.history.content)
 
         if author_list:
-            self.add_result("SVN authors: %s" % ', '.join(author_list))
+            self.add_result("SVN authors: %s" % ", ".join(author_list))
 
         if list_items:
             for f, pristine in list_items:
